*******
TidyExc
*******

.. image:: https://img.shields.io/pypi/v/tidyexc.svg
   :target: https://pypi.python.org/pypi/tidyexc

.. image:: https://img.shields.io/pypi/pyversions/tidyexc.svg
   :target: https://pypi.python.org/pypi/tidyexc

.. image:: https://img.shields.io/readthedocs/tidyexc.svg
   :target: https://tidyexc.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/github/workflow/status/kalekundert/tidyexc/Test%20and%20release/master
   :target: https://github.com/kalekundert/tidyexc/actions

.. image:: https://img.shields.io/coveralls/kalekundert/tidyexc.svg
   :target: https://coveralls.io/github/kalekundert/tidyexc?branch=master

Installation
============
Install ``tidyexc`` using ``pip``::

    $ pip install tidyexc

Usage
=====
Coming soon...
